@@ -153,7 +153,6 @@ def volume_weighted_high_low_vol(data = None, vol_threshold = 0.8, up_trend_thre
 
     data['close_ret']=data['close'].pct_change()
 
-
     data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
     data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
 
@@ -181,6 +180,65 @@ def volume_weighted_high_low_vol(data = None, vol_threshold = 0.8, up_trend_thre
         return np.nan
 
 
+def volume_weighted_high_low_vol_cont(data = None,  contravariant = -1., lag = 2, **kwargs):
+    ## aggregating the volumes by lag
+    data.index = range(0,len(data))
+    all_indices = list(reversed(range(len(data) - 1, 0, -lag)))
+    data['aggregated_indice'] = np.nan
+    data['aggregated_indice'].loc[all_indices] = all_indices
+    data['aggregated_indice']= data['aggregated_indice'].fillna(method='bfill')
+    data['aggregated_indice'] = data['aggregated_indice'].astype(int)
+    volumefrom = data.groupby(['aggregated_indice'])['volumefrom'].agg('sum')
+    high = data.groupby(['aggregated_indice'])['high'].agg('max')
+    low = data.groupby(['aggregated_indice'])['low'].agg('min')
+
+    data['aggregated_volume'] =  data['aggregated_indice'].map(volumefrom)
+    data['aggregated_high'] =  data['aggregated_indice'].map(high)
+    data['aggregated_low'] =  data['aggregated_indice'].map(low)
+
+    data = data[::-lag]
+    data = data.iloc[::-1]
+
+    data['hl'] = (data['aggregated_high'] - data['aggregated_low'])/data['aggregated_low']
+    data['volu_hi_low'] = data['aggregated_volume']*data['hl']
+
+    data['close_ret']=data['close'].pct_change()
+
+    data['volu_hi_low_pct_rank'] = data['volu_hi_low'].rank(pct=True)
+    data['close_ret_pct_rank'] = data['close_ret'].rank(pct=True)
+
+    trend_rank = data['close_ret_pct_rank'].iloc[-1]
+    vol_rank = data['volu_hi_low_pct_rank'].iloc[-1]
+
+
+
+    #trend over the all lookback period
+    trend = ((data['close'][-1]-data['close'][0])/data['close'][0])
+    # vol over the all lookback_period
+    weighted_volu_hi_low = data['volu_hi_low'].sum() / data['volumefrom'].sum()
+
+    #trend over the lagging period
+    trend_lag = ((data['close'][-1]-data['close'][-1])/data['close'][-1])
+    weighted_volu_hi_low_lag = data['volu_hi_low'][-1]/ data['volumefrom'][-1]
+
+    trend_ratio = trend_lag/trend
+    vol_ratio = weighted_volu_hi_low_lag/weighted_volu_hi_low
+
+    signal = contravariant * vol_ratio * trend_ratio
+
+    return signal
+
+
+
+    if vol_rank > vol_threshold:
+        if trend_rank > up_trend_threshold:
+            return contravariant
+        elif trend_rank < low_trend_threshold:
+            return -contravariant
+        else:
+            return np.nan
+    else :
+        return np.nan
 
 def slope_induced(data = None, slope_column = 'high', contravariant = -1., **kwargs):
     high_slope = (data[slope_column][-1] - data[slope_column][0]) / len(data)
